---
title: 결제수단
category: 서비스 종류 (결제대행사별 지원서비스) > 결제수단 > 결제수단
seo:
  title: 결제수단
  description: >-
    포트원에서 제공하는 결제수단 목록입니다. 결제 수단은 결제대행사별로 지원 여부가 상이하므로, 결제대행사를 고르기 전 사용하고자 하는
    결제수단을 선택하신 후 그에 맞게 결제대행사 계약을 진행해 주시기 바랍니다.
  keywords:
    - 결제수단 종류
tags:
  - 일반결제
  - 간편결제
  - 해외결제
  - 공통
pgCompanies:
  - 공통
searchTags:
  - 카드결제
  - 신용카드
  - 체크카드
  - 상품권결제
  - 간편결제
  - 휴대폰결제
  - 가상계좌
  - 계좌이체
  - 결제수단종류
  - 해외카드
---

<Callout content="포트원에서 제공 드리는 결제수단을 안내드립니다. 결제대행사별로 지원가능한 결제수단이 상이합니다.
결제대행사 선택시 이용하실 결제수단을 기준으로 결정하실 수도 있습니다." />

## <Highlight text="일반결제" />

### **카드**

체크카드와 신용카드, 기프트카드(선불카드)를 모두 포함한 카드사를 통한 결제수단입니다.

결제대행사(PG)의 결제창에서 카드사를 선택하고 카드사에 맞는 인증화면을 거쳐 결제되는 방식을 의미하며, 일반적으로 가장 많이 사용하시는 방식입니다.

![](/uploads/결제수단/결제수단-종류/일반인증결제demo.gif)

### **계좌이체**

실시간으로 계좌에서 출금되는 방식으로 뱅크페이 앱을 통한 결제수단입니다.





### **가상계좌**

가상의 계좌를 채번(발급)하여 해당 계좌로 입금하는 형태입니다. (무통장입금과 동일함)

가상계좌 방식은 고정식과 회전식으로 구분할 수 있으며 각 서비스별로 지원가능한 결제대행사가 상이합니다.
대부분의 결제대행사에서는 회전식 가상계좌 서비스를 지원합니다.

- 고정식 : 고객별로 특정한 계좌번호가 고정되어 발급되는 형태
- 회전식 : 매 결제시마다 새로운 계좌번호가 채번되는 형태



### **휴대폰 결제**

고객의 휴대폰 요금에서 후불 청구하는 방식의 거래를 의미합니다.





### **상품권 결제**

상품권 결제는 오프라인에서 사용하는 각종 상품권을 온라인 상에서 온라인 캐쉬로 전환하여 결제하는 방식을 의미합니다.\
문화상품권, 도서문화상품권, 스마트문상, 해피머니 등 다양한 상품권으로 결제할 수 있으며, 주로 게임 및 컨텐츠 업종에서 미성년자와 같이 신용카드 사용이 어려운 고객에게 유용한 결제 수단입니다.

## <Highlight text="정기결제" />

### **카드**

체크카드와 신용카드를 이용하여 빌링키를 발급해 사용하는 방식의 결제수단으로 일반적으로 가장 많이 사용하시는 방식입니다.

### **휴대폰 결제**

휴대폰 정보를 이용하여 빌링키를 발급해 사용하는 방식의 결제수단입니다. 휴대폰 빌링키의 경우 매월 동일한 금액으로만 결제가 가능합니다.

## <Highlight text="간편결제" />

간편결제사에 이미 회원가입 되어있는 고객이라면 어려운 인증과정 없이 편리하게 결제가 가능한 방식입니다. 예를 들어 카카오페이에 이미 국민카드를 등록해놓은 고객이라면, 카카오페이를 통해 생체 인증 혹은 비밀번호 인증만으로 결제가 가능합니다.

간편결제를 이용하실 수 있는 방법은 2가지로 다음과 같습니다. 참고로 아래 2가지 방식은 동시에 사용이 불가하여 한 가지 방식을 선택해주셔야 합니다.

### **간편결제사와 직접 계약**

포트원을 통해 간편결제사와 직접 계약을 맺는 방식으로 원하시는 결제사를 선택하신 후 결제사와 각각 계약을 진행해야 합니다.

### **허브형 간편결제**

간편결제사와 직접 계약을 맺지 않고도 일반 결제대행사를 통한 사용이 가능합니다.\
일반결제를 통해 이미 카드, 계좌이체 등의 서비스를 사용중이라면 허브형 간편결제를 통해 별도 추가 계약없이 간편결제를 도입할 수 있습니다.
